@@ -17,8 +17,8 @@ def run_training() -> None:
         random_state=config.model_config.random_state,
     )
     
-    X_train = pd.DataFrame(X_train, columns = config.model_config.features)
-    X_test = pd.DataFrame(X_test, columns = config.model_config.features)
+    X_train = pd.DataFrame(X_train, columns = config.model_config.columns)
+    X_test = pd.DataFrame(X_test, columns = config.model_config.columns)
     Y_train = pd.DataFrame(Y_train, columns = config.model_config.target)
     Y_test = pd.DataFrame(Y_test, columns = config.model_config.target)
     
